@@ -16,6 +16,7 @@ SMS_AUTH_SETTINGS.setdefault("SMS_AUTH_CODE_LEN", 4)
 # MESSAGES
 SMS_AUTH_SETTINGS.setdefault("SMS_CODE_NOT_FOUND", "Code not found")
 SMS_AUTH_SETTINGS.setdefault("SMS_WAIT_TIME", "Code was send early")
+SMS_AUTH_SETTINGS.setdefault("SMS_USER_ALREADY_EXIST", "User already exist")
 SMS_AUTH_SETTINGS.setdefault(
     "SMS_REQUEST_SUCCESS", "Your request was successfully processed"
 )
@@ -56,6 +57,7 @@ class Conf:
     SMS_DEBUG = SMS_AUTH_SETTINGS.get("SMS_DEBUG")
     SMS_DEBUG_CODE = SMS_AUTH_SETTINGS.get("SMS_DEBUG_CODE")
     SMS_CODE_NOT_FOUND = SMS_AUTH_SETTINGS.get("SMS_CODE_NOT_FOUND")
+    SMS_USER_ALREADY_EXIST = SMS_AUTH_SETTINGS.get("SMS_USER_ALREADY_EXIST")
     SMS_WAIT_TIME = SMS_AUTH_SETTINGS.get("SMS_WAIT_TIME")
     SMS_REQUEST_SUCCESS = SMS_AUTH_SETTINGS.get("SMS_REQUEST_SUCCESS")
     SMS_CELERY_FILE_NAME = SMS_AUTH_SETTINGS.get("SMS_CELERY_FILE_NAME")
