@@ -1,3 +1,5 @@
+from django.contrib.auth import get_user_model
+
 from ..api.exceptions import RestApiException
 from ..conf import conf
 from ..models import PhoneCode
@@ -20,6 +22,10 @@ class GeneratorService(SmsService):
 
             code.delete()
 
+        if self.owner is not None:
+            if get_user_model().objects.filter(username=self.owner).exists():
+                raise RestApiException(detail={"detail": conf.SMS_USER_ALREADY_EXIST})
+
         PhoneCode.objects\
             .create(phone_number=self.phone_number,
                     owner=self.owner)
